@@ -6,6 +6,7 @@
 
 __author__ = 'fszostak@gmail.com'
 
+from os import environ
 import sys
 import getopt
 import traceback
@@ -21,7 +22,7 @@ def main():
     engine = None
     command = None
 
-    help_message = '\npwbus [-e <engine>] [-c <channel> start\n\n      -e <redis|socket>\n      --engine=<redis|socket>\n\n      -c <channel_id>\n      --channel=channel_id\n\n      start the server\n'
+    help_message = '\npwbus -f <registry-config-file> [-e <engine>] [-c <channel> start\n\n      -f  <registry-config-file>\n      --registry=<registry-config-file>\n      -e <redis|socket>\n      ----engine=<redis|socket>\n\n      -c <channel_id>\n      --channel=channel_id\n\n      start the pwbus server\n'
 
     try:
         opts, args = getopt.getopt(argv, "he:c:", ["start|channel=|engine="])
@@ -39,6 +40,8 @@ def main():
             engine = arg
         elif opt in ("-c", "--channel"):
             channel = arg
+        elif opt in ("-f", "--registry-file"):
+            environ['PWBUS_REGISTRY'] = arg
 
     for arg in args:
         if arg == "start":
